==> nextcloud-16.0.1.zip: nextcloud/apps/updatenotification/l10n/pt_BR.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} está disponível. Obtenha mais informações sobre como atualizar.",
    "Update notifications" : "Notificações de atualização",
    "Channel updated" : "Canal atualizado",
    "The update server could not be reached since %d days to check for new updates." : "O servidor de atualização não foi encontrado já há %d dias para verificar por novas atualizações.",
    "Please check the Nextcloud and server log files for errors." : "Verifique se há erros nos arquivos de log do servidor e do Nextcloud ",
    "Update to %1$s is available." : "Atualização para %1$s está disponível.",
    "Update for %1$s to version %2$s is available." : "Atualização de %1$s para versão %2$s está disponível.",
    "Update for {app} to version %s is available." : "Atualização para {app} para a versão %s está disponível.",
    "Update notification" : "Notificação de atualização",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Exibe notificações de atualização para o Nextcloud e fornece o SSO para o atualizador.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "A versão que você está executando não é mais mantida. Por favor, atualize para uma versão suportada o mais rápido possível.",
    "Apps missing updates" : "Aplicativos faltando atualizações",
    "View in store" : "Ver na loja",
    "Apps with available updates" : "Aplicativos com atualizações disponíveis",
    "Open updater" : "Abrir atualizador",
    "Download now" : "Baixar agora",
    "What's new?" : "O que há de novo?",
    "The update check is not yet finished. Please refresh the page." : "A verificação de atualização ainda não acabou. Atualize a página.",
    "Your version is up to date." : "Sua versão está atualizada.",
    "A non-default update server is in use to be checked for updates:" : "Um servidor de atualização não padrão está sendo verificado por atualizações:",
    "Update channel:" : "Atualizar para:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Você sempre pode atualizar para uma versão mais recente. Mas nunca pode voltar à uma versão mais estável.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Observe que após uma nova versão pode levar um tempo até aparecer aqui. Lançamos novas versões distribuídas ao longo do tempo para nossos usuários e às vezes pulamos uma versão quando problemas são encontrados.",
    "Notify members of the following groups about available updates:" : "Notificar membros dos seguintes grupos sobre atualizações disponíveis:",
    "Only notification for app updates are available." : "Só está disponível notificação para atualizações de aplicativos.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "A atualização selecionada fornece notificações dedicadas para o servidor desatualizado.",
    "The selected update channel does not support updates of the server." : "A atualização selecionada não fornece suporte a atualizações do servidor.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Uma nova versão está disponível: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Verificado em {lastCheckedDate}",
    "Checking apps for compatible updates" : "Verificando atualização dos aplicativos",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Certifique-se de que seu config.php não tenha configurado <samp>appstoreenabled</samp> para falso.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Não foi possível conectar a appstore ou não havia atualização. Procure manualmente por atualizações ou verifique se o servidor tem acesso à internet.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Todos</strong> os aplicativos tem uma atualização disponível",
    "View changelog" : "Visualizar registro de alterações",
    "Stable" : "Estável",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "A versão estável mais recente. É adequada para uso regular e será sempre atualizada para a versão principal mais recente.",
    "Production" : "Produção",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Sempre fornecerá o nível de patch mais recente, mas não será atualizado para a próxima versão principal imediatamente. Essa atualização geralmente acontece com a segunda versão secundária (x.0.2) e somente se a instância já estiver na versão secundária mais recente.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Uma versão de pré-lançamento para testar novos recursos, não indicada para produção.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplicativo não tem atualização disponível","<strong>%n</strong> aplicativos tem uma atualização disponível"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Você pode atualizar para uma versão mais nova ou experimental. No entanto, nunca poderá voltar para uma versão estável ou antiga.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "A <strong>produção</strong> sempre fornecerá o nível de patch mais recente, mas não será atualizada para a próxima versão principal imediatamente. Essa atualização geralmente acontece com o segundo lançamento menor (x.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>estável</strong> é a versão estável mais recente. É adequado para uso regular e será sempre atualizado para a versão principal mais recente.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>beta</strong> é uma versão de pré-lançamento apenas para testar novos recursos, não para ambientes de produção.",
    "Could not start updater, please try the manual update" : "Não foi possível iniciar o atualizador, tente a atualização manual"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-17.0.0.zip: nextcloud/apps/updatenotification/l10n/pt_BR.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} está disponível. Obtenha mais informações sobre como atualizar.",
    "Channel updated" : "Canal atualizado",
    "Update notifications" : "Notificações de atualização",
    "The update server could not be reached since %d days to check for new updates." : "O servidor de atualização não foi encontrado já há %d dias para verificar por novas atualizações.",
    "Please check the Nextcloud and server log files for errors." : "Verifique se há erros nos arquivos de log do servidor e do Nextcloud ",
    "Update to %1$s is available." : "Atualização para %1$s está disponível.",
    "Update for %1$s to version %2$s is available." : "Atualização de %1$s para versão %2$s está disponível.",
    "Update for {app} to version %s is available." : "Atualização para {app} para a versão %s está disponível.",
    "Update notification" : "Notificação de atualização",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Exibe notificações de atualização para o Nextcloud e fornece o SSO para o atualizador.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "A versão que você está executando não é mais mantida. Por favor, atualize para uma versão suportada o mais rápido possível.",
    "Apps missing updates" : "Aplicativos faltando atualizações",
    "View in store" : "Ver na loja",
    "Apps with available updates" : "Aplicativos com atualizações disponíveis",
    "Open updater" : "Abrir atualizador",
    "Download now" : "Baixar agora",
    "What's new?" : "O que há de novo?",
    "The update check is not yet finished. Please refresh the page." : "A verificação de atualização ainda não acabou. Atualize a página.",
    "Your version is up to date." : "Sua versão está atualizada.",
    "A non-default update server is in use to be checked for updates:" : "Um servidor de atualização não padrão está sendo verificado por atualizações:",
    "Update channel:" : "Atualizar para:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Você sempre pode atualizar para uma versão mais recente, mas nunca pode voltar à uma versão mais estável.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Observe que após uma nova versão pode levar um tempo até aparecer aqui. Lançamos novas versões distribuídas ao longo do tempo para nossos usuários e às vezes pulamos uma versão quando problemas são encontrados.",
    "Notify members of the following groups about available updates:" : "Notificar membros dos seguintes grupos sobre atualizações disponíveis:",
    "Only notification for app updates are available." : "Só está disponível notificação para atualizações de aplicativos.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "A atualização selecionada fornece notificações dedicadas para o servidor desatualizado.",
    "The selected update channel does not support updates of the server." : "A atualização selecionada não fornece suporte a atualizações do servidor.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Uma nova versão está disponível: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Verificado em {lastCheckedDate}",
    "Checking apps for compatible updates" : "Verificando atualização dos aplicativos",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Certifique-se de que seu config.php não tenha configurado <samp>appstoreenabled</samp> para falso.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Não foi possível conectar a appstore ou não havia atualização. Procure manualmente por atualizações ou verifique se o servidor tem acesso à internet.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Todos</strong> os aplicativos tem uma atualização disponível",
    "View changelog" : "Visualizar registro de alterações",
    "Enterprise" : "Empresarial",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Fornece sempre o nível de patch mais recente, mas não será atualizado para a próxima versão principal imediatamente. Essa atualização acontece assim que a Nextcloud GmbH fizer mais ajustes e testes para implantações de larga escala e missão crítica. Este canal está disponível apenas para clientes do Nextcloud Enterprise.",
    "Stable" : "Estável",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "A versão estável mais recente. É adequada para uso regular e será sempre atualizada para a versão principal mais recente.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Uma versão de pré-lançamento para testar novos recursos, não indicada para produção.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplicativo não tem atualização disponível","<strong>%n</strong> aplicativos tem uma atualização disponível"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Você pode atualizar para uma versão mais nova ou experimental. No entanto, nunca poderá voltar para uma versão estável ou antiga.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "A <strong>produção</strong> sempre fornecerá o nível de patch mais recente, mas não será atualizada para a próxima versão principal imediatamente. Essa atualização geralmente acontece com o segundo lançamento menor (x.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>estável</strong> é a versão estável mais recente. É adequado para uso regular e será sempre atualizado para a versão principal mais recente.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>beta</strong> é uma versão de pré-lançamento apenas para testar novos recursos, não para ambientes de produção.",
    "Production" : "Produção",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Sempre fornecerá o nível de patch mais recente, mas não será atualizado para a próxima versão principal imediatamente. Essa atualização geralmente acontece com a segunda versão secundária (x.0.2) e somente se a instância já estiver na versão secundária mais recente."
},
"nplurals=2; plural=(n > 1);");
